##  Jury et avis de Poursuites d'Etudes

Partant d'un semestre sélectionné, l'onglet **Statistiques > Documents Avis de Poursuite d'Etudes** (ci-dessous appelé **outil PE**) propose une aide à la tenue du jury et à l'édition des avis de poursuites d'études pour les étudiants de DUT.

###  Les tags

Les avis (demandés par les différents établissements post-DUT) attendent fréquemment des moyennes transverses aux modules voire aux
semestres du PPN : par exemple, moyenne sur les matières théoriques, les matières techniques,
moyenne en français, etc...

L'outil PE permet le calcul de ces moyennes en utilisant des **tags** affectés aux modules dans le **Programme** de formation.
Tous les modules portant le même tag (attention à la casse et à l'accentuation) seront intégrés ensemble dans le calcul de la moyenne.

Voici l'exemple du programme du DUT RT taggué (figure ci-dessous), où par exemple, le tag *mathématiques* est affecté à tous les
modules du programme en lien avec des maths.

Les tags peuvent également faire mention d'un coefficient servant à la pondération des modules dans le calcul de la moyenne (cf. section coefficient).
Le tag sera alors de la forme : `nom_du_tag:coeff_entier`.

Un tag *dut* reprenant la moyenne de l'étudiant à chaque semestre est automatiquement ajouté.

![programmeRTtaggue.png](screens/programmeRTtaggue.png)


###  Les moyennes

####  Les moyennes intra et inter semestres

Au delà du "thème" des moyennes, les avis attendent parfois que ces moyennes soient calculées sur plusieurs semestres : moyenne en 1ère année, en 2ème année
voire (pour le jury) sur l'ensemble du parcours de l'étudiant. 8 plages de calculs temporelles sont donc prévus pour ces moyennes : pour chaque tag,

 * le label **S1** (respectivement S2, S3, S4) désigne une moyenne sur ce tag calculée sur le **S1** (respectivement S2, S3, S4) - ou plus précisement sur les modules du **S1** (respectivement S2, S3, S4) ayant été associé au tag considéré
 * le label **1A** (respectivement 2A) désigne une moyenne sur ce tag calculée sur la **première année** (respectivement la deuxième année) - ou plus précisement sur tous les modules **du S1 et du S2** (respectivement du S3 et du S4) ayant été associé au tag considéré
 * le label **3S** (souvent utilisé dans un jury de poursuites d'études se tenant juste après le S3) désigne une moyenne sur ce tag calculée sur l'**ensemble du parcours allant du S1 au S3** (inclus) - ou plus précisement sur tous les modules **du S1, S2, S3** ayant été associé à ce tag.
 * le label **4S** désigne une moyenne sur ce tag calculée sur l'**ensemble du parcours allant du S1 au S4** (inclus) - donc plus précisement sur tous les modules du programme ayant été associé à ce tag.

####  Les coefficients de pondération

Par défaut, les moyennes calculées sur les modules associés à un tag donné utilisent
les coefficients de pondération des modules dans le programme DUT, ramenés au total des
coefficients dans les semestres qui les concernent : partant d'un semestre \(i\), en notant :

 * \(m_{i,j}\) la note d'un étudiant à un module associé au tag dans le semestre \(i\) (\(j\) donnant donc le numéro du module au sein du semestre parmi les modules associés au tag),
 * \(c_{i,j}\) le coefficient du module \(m_{i,j}\) dans le programme de formation

alors la moyenne \(M_i\) associée au tag pour le semestre \(i\) est calculée avec :
$$
M_i = \frac{ \sum_{j} c_{i,j} m_{i,j} }{ \sum_{j} c_{i,j} }
$$

En notant ensuite \(c_i\) la somme des coefficients des modules du semestre \(i\) associé au tag considéré (ici \(c_i = \sum_{j} c_{i,j}\))
et \(C_i\) la somme des coefficients de tous les modules (y compris ceux n'étant pas associés au tag considéré) du semestre \(i\) (donc \(C_i \geq c_i\)), la
moyenne \(M\) associée au tag sur les 4 semestres de formation (donc de label **4S**) est calculée avec :
$$
M = \frac{ \sum_{i} \frac{c_i}{C_i} M_i }{ \sum_{i} \frac{c_i}{C_i} }
$$
Plus simplement, le poids des modules associés au tag au sein d'un semestre est conservé dans le calcul de la moyenne.

L'outil PE offre la possibilité de recoefficienter les modules associés au tag dans le calcul de la moyenne en
leur joignant un (éventuel) coefficient de pondération supplémentaire entier \(p_{i,j}\) (voir section Les tags).

Dans ce cas, la moyenne \(M_i\) associée au tag sur le semestre \(i\) est impactée avec :
$$
M_i = \frac{ \sum_{j} p_{i,j} c_{i,j} m_{i,j} }{ \sum_{j} p_{i, j} c_{i,j} }
$$
La somme des coefficients des modules dans le semestre \(c_i\) devient \(c_i = \sum_{j} p_{i,j} c_{i,j}\) mais la somme
des coefficients de tous les modules \(C_i\) reste inchangée.

Plus simplement, l'idée de cette pondération est de conserver le poids des modules au sein du semestre
tout en accord plus d'importance (lorsque \(p_{i,j} > 1\)) à la note obtenue par l'étudiant.

Le calcul des moyennes intra-semestres (1A, 2A ou 3S) est basée sur le même principe en n'utilisant que les semestres concernés.

####  Cas des étudiants redoublants

Dans le cas des étudiants redoublants (par exemple ayant fait 2 semestres S1), ne sont conservés que les notes obtenues dans les UE validées
par les décisions de jury : dans l'exemple, il s'agira (le plus souvent) des notes du S1 le plus récent, sauf pour un étudiant qui aurait capitalisé
une UE et dont une partie des notes proviendrait de son UE capitalisée.

###  Les classements et les statistiques

Les avis demandent souvent le classement associé à la moyenne obtenue sur un tag et pour un temps donné (label 1A, 2A, ...) avec l'ambiguité
de la cohorte considérée. Ce classement peut aller de pair avec des données statistiques (nombre d'étudiants, note minimum, maximum, moyenne sur la cohorte).
L'outil PE propose deux cohortes et donc deux séries de classement/statistique par tag et label temporel.

####  La "cohorte" filière

Est appelé filière l'ensemble des étudiants inscrits dans le même semestre temporel que le dernier impliqué dans la moyenne calculée. Prenons l'exemple
d'une moyenne sur le tag mathématiques portant sur le label 3S (c'est à dire sur les semestres S1, S2, et S3). La filière sera l'ensemble des étudiants inscrits
dans le S3. Dans ce S3, pourront se trouver des étudiants de différents parcours comme :

 * des étudiants "standards" avec S1 validé, S2 validé, S3 validé (du premier coup)
 * des étudiants redoublants avec (par exemple) un parcours de la forme S1 validé, S2 non validé, S3 non validé, S2 validé, S3 validé (dont étant entrés à l'IUT un an avant les étudiants "standards").

De fait, les notes prises en compte pour les étudiants standards et les étudiants redoublant pourront provenir de modules ne s'étant pas tenus
aux même universitaires. Les seuls modules communs garantis seront ceux du S3 (aka le dernier semestre de l'ensemble S1+S2+S3).

####  La "cohorte" promo

Est appelé promo 20XX l'ensemble des étudiants susceptibles de valider leur diplôme DUT en date de juillet 20XX quelque soit le programme de formation DUT
suivi.

Par exemple, la promo 2017 inclut les étudiants qui valideront leur S4 en juillet 2017 ; ceux ayant validé leur S4 en juillet 2016 appartiennent à la promo 2016.
Parmi les étudiants de la promo 2017, on retrouve les étudiants "standards" étant entrés à l'IUT en septembre 2015 avec un parcours S1 validé, S2 validé, S3 validé et S4 validé.
On retrouve également les étudiants entrés à l'IUT en septembre 2014 et ayant redoublé 1 à 2 semestres donc validant leur S4 entre janvier et juillet 2017. Les étudiants
ayant démissionnés ou s'étant réorientés (aka. ne s'étant pas réinscrit dans un semestre DUT là où il aurait "du" le faire) sont exclus de la promo.

Remarque: les calculs des étudiants de la promo fonctionnent à condition que les dates des semestres de début d'année universitaire s'étalent sur 2 années civiles (par exemple
S1 de septembre 2016 à janvier 2017) et que les dates des semestres de fin d'année universitaire sont limitées à une année civile (par exemple S2 de janvier à juillet 2017).

####  Les classements

Un élève au regard de sa moyenne à un tag, sur un laps de temps donné (label S1, 1A, 3S, ...) est donc classé soit sur sa filière soit sur la promo. Les statistiques
du groupe (que ce soit la filière ou la promo), plus précisément la note minimum, maximum et la moyenne du groupe sont également fournies.

##  L'export du tableur récapitulatif

L'onglet PE renvoie une archive zip pour une promotion d'élèves diplômés en 20XX,
contenant notamment un fichier Jury_PE_20XXjurySyntheseDict_20XX_v2.xls. Ce fichier récapitule l'ensemble des moyennes, des classements et des statistiques
des élèves dont le S4 sera (prévisiblement) validé en 20XX. Le fichier contient un tab par tag saisi dans le programme. Par défaut, un tag est présent :
le tag dut. En plus des données numériques, on retrouve pour chaque élève la liste des semestres parcourues (colonne P1 à P6).



##  Les avis PE au format LaTeX

L'archive zip contient également un export des données de poursuites d'études de la promotion d'élèves au format LaTeX (fichier .tex) pour permettre (après compilation latex à faire sur votre machine) de génerer des avis de poursuites d'études des étudiants "quasi prêts à l'emploi" (pour impression ou envoi par mail). 

###  Arborescence LaTeX

Les sources latex (fournies ici dans le fichier zip exporté par ScoDoc) s'articulent autour de l'arborescence suivante : 
```
avis.tex                                    # Fichier principal point d'entrée du compilateur latex
avis_poursuite.tex                          # Fichier permettant d'inclure les avis des étudiants et fourni par ScoDoc
avis_poursuite_nom_prenom_identifiant.tex   # Avis de poursuite d'études d'un étudiant généré suivant le template
avisPE.cls                                  # Classe LaTex pour paramètrant la mise en page du document
README.txt                                  # Informations de configuration pour les administrateurs de ScoDoc
logos                                       # Répertoire contenant les figures (375 x 256 où toutes autres proportions équivalentes)
    + logo_header.png                       # Le logo de l'établissement à adapter à vos besoins
    + logo_footer.png                       # Un second logo pour le pied de page
modeles                                     # Répertoire contenant des macros pour la mise en forme latex
    + un_avis.tex                           # Modèle pour la génération de avis_poursuite_nom_prenom_EID0000.tex
    + parcourstimeline.tex                  # Ligne temporelle retraçant le parcours d'un étudiant
    + un_footer.tex                         # Modèle pour le pied de page des avis PE
```

La compilation pourra se lancer avec : `pdflatex avis.tex`


###  Template LaTeX

Les avis LaTeX sont générés à partir de deux *templates latex*, dont le contenu est fourni dans modeles/un_avis.tex et modeles/un_footer.tex de l'archive avis.zip. 

Ces templates sont livrés avec l'installation standard de ScoDoc. 

Vous pouvez également copier leur contenu dans les paramètres de ScoDoc, onglet **Paramétrage > Template LaTeX des avis** pour le modèle un_avis.tex et onglet **Paramétrage > Code LaTeX en fin d'avis** pour le modèle un_footer.tex. Vous pourrez ainsi par la suite les modifier à votre guise en respectant le format décrit ci-dessous. 

###  Signataire des avis de PE

Le nom du signataire qui sera apposé sur les avis de poursuites d'études est à saisir dans les paramètres de ScoDoc, onglet **Paramétrage > Nom du responsable des poursuites d'études**.


###  Les sources LaTeX fournis par l'outil PE

L'outil PE renvoie dans l'archive `Jury_PE_20XX.zip` de la promotion d'élèves diplômés en 20XX, où vous trouverez :

 1. un fichier par étudiant de la promotion. Ce fichier est nommé sous la forme `avis_poursuite_nom_prenom_identifiant.tex` ; il synthétise les résultats et les moyennes de l'étudiant au cours de sa scolarité DUT en suivant les *templates latex* un_avis.tex et un_footer.tex. 

 2. un fichier `avis_poursuite.tex` qui liste tous les avis des étudiants à compiler (inclusion des fichiers latex de chaque étudiant). 


####  Pour obtenir le document PDF 

1. Ouvrez  l'archive zip renvoyée par ScoDoc dans votre *répertoire de travail*.

2. Dans une invite de commande (cmd en Windows, terminal en linux) dont le répertoire courant est celui créé à l'ouverture de l'archive (commande `cd Jury_PE_...`), lancez la compilation des avis en exécutant la commande : 
```
pdflatex avis.tex 
```
Le résultat est le classeur **avis.pdf**.

Cette compilation déclenche celle de `avis_poursuite.tex` qui elle-même lancera celle des avis par étudiants `avis_poursuite_nom_prenom_identifiant.tex` faisant partie de la promotion ciblée (on pourra commenter les avis des étudiants que l'on ne souhaite pas compiler en faisant débuter la ligne d'inclusion de leur avis dans `avis_poursuite.tex` d'un %). 

###  Le rendu PDF du template proposé

Le template proposé permet un résultat similaire à celui de la capture d'écran : 

 * page1 : ![avis1.png](screens/avis1.png)

 * page2 : ![avis2.png](screens/avis2.png)

En l'état, il fournit pour chaque étudiant :

 * son nom, son prénom, son âge;
 * une frise temporelle décrivant tous les semestres DUT dans lesquels il a été inscrit (avec la nomenclature que vous avez choisi dans ScoDoc);
 * un bilan synthétique de ses moyennes aux différents semestres (avec ses classements dans son groupe et dans sa promo - voir section "les classements et les statistiques" pour l'interprétation des cohortes);
 * une zone d'annotation permettant un commentaire individualisé, l'annotation étant recherchée parmi les annotations du profil ScoDoc de l'étudiant (cf. section "L'annotation PE").

###  L'annotation PE

Lorsqu'on édite la fiche d'un étudiant, il est possible de saisir des annotations à son sujet. Ces annotations sont aussi utilisées ici pour saisir un commentaire individualisé à apposer sur l'avis de poursuites d'études au format LaTeX de l'étudiant. Pour distinguer ce commentaire des annotations plus standards, l'annotation doit débutée par un mot-clé (ici PE:) comme le montre la capture d'écran ci-dessous :

   ![annotation_PE.png](screens/annotation_PE.png)
 

Cette annotation sera alors automatiquement ajoutée à l'avis LaTeX de l'étudiant (cf. `avis_poursuite_nom_prenom_identifiant.tex`).

L'annotation peut bien entendue être remodifiée (ou ajoutée si manquante) à la main dans le fichier `avis_poursuite_nom_prenom_identifiant.tex` avant compilation en pdf. 

Plusieurs annotations ayant trait à un commentaire PE peuvent également être mémorisées dans ScoDoc (à condition de les faire toutes précéder du tag "PE:"). Dans ce cas, seule la plus récente sera ajoutée à l'avis LaTeX de l'étudiant. 

Enfin, il est possible de modifier le tag (ici "PE:") identifiant les commentaires PE dans les annotations en allant dans l'onglet **Paramètrage > Tag désignant l'avis PE** et en y saisissant votre tag (éviter les caractères spéciaux propres au HTML, comme le ">"). 

###  Personnaliser son template

####  Les patterns de base

Les templates d'avis (un_avis et un_footer) sont des codes LaTeX classiques que vous pouvez adaptez à loisir à vos besoins. 

Ils interprètent également une série de **patterns**, reconnaissables au fait qu'elles sont toutes encapsulées par deux séries de doubles * ; ces patterns sont traitées par ScoDoc pour accéder aux données de l'étudiant. Ainsi:

 * `**nom**` sera remplacé par le nom de l'étudiant
 * `**prenom**` par le prénom
 * `**age**` par son age (à la date de création des fichiers tex)
 * `**sexe**` par son genre

Plusieurs **patterns/macros** sont proposées :

 * `**parcourstimeline**` ajoute le code LaTeX pour retracer le parcours de l'étudiant (les différents semestres dans lesquels il a été inscrit) sous la forme d'une frise temporelle (cf. capture d'écran précédente)
 * `**bilanParTag**` ajoute le code LaTeX d'un tableau, qui synthétise - pour tous les tags (sauf le tag *dut*) que vous avez affecté aux semestres de l'étudiant (cf. section Les tags) ses résultats aux différents aggrégats proposés (S1, S2, S3, S4, 1ère année, 2ème année, S1+S2+S3 et totalité du DUT)

####  Les patterns personnalisées

Tous les éléments calculés pour le jury de poursuite d'études sont également accessibles sous la forme *aggregat:cohorte:tag:critere** où :

 * aggregat est l'un des aggrégats parmi S1, S2, S3, S4, 1A, 2A, 3S ou 4S; 
 * cohorte est soit groupe soit promo (suivant la "cohorte" que l'on souhaite prendre en compte);
 * tag est l'un des tags que vous avez déclarés dans ScoDoc (dut étant proposé par défaut);
 * critere est l'un des calculs faits pour établir le jury parmi note (la note de l'étudiant), rang (le rang dans la cohorte), min, max, moy (le minimum, le maximum ou la moyenne de la cohorte). 

Par exemple, 

 * **S2:groupe:mathématiques:note** sera remplacé par la note-moyenne de l'étudiant en mathématiques pour le S2;
 * **4S:promo:dut:rang** sera remplacé par le rang de l'étudiant, calculé au sein de la promo, sur sa note moyenne de DUT (moyenne calculée sur les 4 semestres S1+S2+S3+S4);
 * **1A:promo:physique:min** sera remplacé par la plus petite note de la promo obtenue en physique (moyenne de tous les modules tagués physique) sur toute la 1ère année (S1+S2).



