
# Le Bachelor Universitaire de Technologie (BUT)

Formation en trois ans dispensées par les IUT français, introduite en 2021, et
basée sur une forme d'approche par compétences nécessitant un système
d'évaluation spécifique.

Cette page décrit les principaux éléments du BUT utiles à comprendre pour le
gérer avec ScoDoc. Pour les curieux, la page 
[modélisation des parcours BUT](ModelisationParcoursBUT.md)
donne quelques détails sur la façon dont ScoDoc organise les objets du BUT.


## UE, modules, évaluations

 - UE : Unité d'Enseignement, associée à des crédits (ECTS) et validée (ou non)
   en jury. Une UE est rattachée à une *formation*.
 
 - Module: dans ScoDoc, un module désigne une dispositif pédagogique, évalué.
   Dans les formations BUT, le module prend la forme d'une *ressource* ou d'une
   SAE (*situation d'apprentissage et d'évaluation*). Un module est rattaché à
   une (seule) UE. 

   Dans le BUT, un module est aussi associé à une ou ou plusieurs UE, cette
   association étant affecté de *coefficients* (une valeur par UE associée). 
 
 - Évaluation: dispositif produisant une note pour les étudiants inscrits à un
   module. L'évaluation est associée à des coefficients.

## Structure des formations par compétences de type BUT

L'architecture d'une formation BUT est définie par les éléments suivants:

  - Compétence
    - Niveau 
    - Composantes essentielles ("En respectant les règles métiers...")
    - Situations professionnelles ("Surveillance de la qualité de la
      production...")

  - Niveaux de compétence: associés à une année. Attention, le niveau 1 commence
    parfois en deuxième année.
      - Numéro (1, 2, 3)
      - Titre
      - Apprentissages critiques (AC): "Identifier les dysfonctionnements du réseau local..."

Chaque niveau se décompose en deux UE (aka "regroupement cohérent d'UE"), en
semestres impair et pair d'une année scolaire.

La figure ci-dessous indique la correspondance entre compétences (découpées en
niveaux) et UEs.

<img src="/fig/but-competences-ues.png" width="70%">

## Calcul des notes

Les rôles des SAÉ et ressources étant symétriques, on appellera dans la suite (et
dans ScoDoc) *module* un objet de type SAÉ _ou_ ressource.

Dans la suite, on considère les poids et coefficients toujours positifs ou
nuls (pas de coefficients négatifs).

### Coefficients des SAÉ et ressources
Les coefficients des modules (ressources et SAÉ) sont fixés par le PN (*adapté
localement*). 

Traditionnellement, chaque module $m$ est noté par une note (moyenne de ses
évaluations) représentée par le nombre $\mu_m$. Si $c_{u,m}$ désigne le coefficient du
module $m$ dans l'UE $u$, la moyenne d'UE de l'étudiant est 

$$\mu_u = \frac{1}{\sum_m c_{u,m}} \, \sum_{m \in u} c_{u,m} \, \mu_m$$

Mais pour le BUT, on souhaite avoir des évaluations associées à un
sous-ensemble de compétences (par exemple via des *apprentissages critiques*),
ce qui se traduit par une note envoyée vers certaines UE mais pas toutes, comme
on le voit dans exemples suivants:

L'exemple ci-dessous est un extrait du référentiel de compétence du BUT GEII. On
voit que les SAÉ et les ressources sont affectées de coefficients dans les deux
UE de ce semestre (S2), ici à parts égales sauf pour les SAÉs 2.1 et 2.2, dites
"mono-compétences", qui contribuent chacune à une seule UE.

<img src="/fig/but-ref-comp-ex-geii.jpg" width="70%">


Un autre exemple, cette fois avec des coefficients différents et un nombre plus
réduit d'apprentissages critiques:
![but-ref-comp-ex-commente](fig/but-ref-comp-ex-commente.png)

### Note d'un module

La note (moyenne) d'un module (SAÉ ou ressource) se calcule à partir de ses
évaluations. Chaque évaluation est pondérée, par un poids $p$ est fixé par
l'enseignant. Ce poids joue le même rôle que le coefficient d'une évaluation
classique, mais peut se décliner en plusieurs valeurs, une par UE associée au
module. 

Soit $n_e$ la note à l'évaluation $e$ du module $m$, et $p_{e, u}$ son poids
vers l'UE $u$. La somme des notes d'un module pour l'UE $u$ est: 

$$n_u = \sum_e p_{e,u} \, n_e$$

Chaque UE indiquée par le référentiel de formation doit être évaluée: si le
coefficient du module vers l'UE $u$ est non nul, la somme des poids vers 
une UE $u$ *doit* être non nulle; si ce n'est pas le cas, le module sera déclaré
*non conforme* et le jury ne pourra pas être tenu. 


### Moyenne de module (SAÉ ou ressource)
La moyenne d'un étudiant dans un module est un vecteur, car on a une note moyenne par UE:

$$\mu_{m, u} = \frac{\sum_e p_{e,u} \, n_e}{\sum_{e} \, p_{u,e}}$$

Toutefois, une moyenne *scalaire* (un nombre entre 0 et 20) est calculée à
titre indicatif (et sera éventuellement utilisée dans certaines fonctions de
ScoDoc conçues avant le BUT):

$$\mu_m = \frac{\sum_e (\sum_u p_{e,u}) \, n_e}{\sum_{u,e} \, p_{u,e}}$$

### Calcul moyenne d'UE

On va considérer les coefficients de modules et d'évaluations:

$$\mu_u = \frac{1}{\sum_m c_{u,m}} \, \sum_{m \in u} c_{u,m} \, \frac{\sum_e p_{e,u} \, n_e}{\sum_{e} \, p_{e,u}}$$

L'exemple suivant illustre ce mode de calcul:

<img src="/fig/but-exemple-calcul-notes.png" width="70%">

Par ailleurs, il est (parfois, peut-être) utile de calculer des moyennes par
pôles au sein de l'UE: pôle SAÉ, pôle ressource.

### Validation d'une UE
La validation ou non d'une UE dépend uniquement de la moyenne générale (et des
conditions habituelles d'assiduité et de défaillance spécifiées dans les
règlements des établissements):

<img src="/fig/but-validation-ue.png" width="50%">

Voir plus loin la gestion du parcours et les règles d'obtention du diplôme, qui
peuvent entrainer la validation d'UE a posteriori.

### Capitalisation

Les UE sont capitalisables, c'est à dire qu'un étudiant conserve son UE s'il
arrête temporairement ses études ou redouble un semestre.

En cas de redoublement, l'étudiant qui choisi de répéter une UE conserve le
résultat antérieur sauf s'il obtient mieux. 

### Moyenne générale

La validation du BUT ne considère pas de "moyenne générale": chaque
regroupement d'UE est considéré indépendamment (aucunes compensations entre UE
relevant de compétences différentes).

Cependant, ScoDoc calculera une moyenne générale indicative, utile pour
certaines opérations (tri de tableaux, création de groupe de niveaux semblables,
avis de poursuite d'études, etc.).

Cette moyenne sera calculée en utilisant les ECTS de chaque UE du semestre
considéré:

$$ g = \frac{1}{\sum_{u \in \cal S} \mbox{ects}_u} \sum_{u \in \cal S} \mbox{ects}_u \,  \mu_u $$

### Passage d'une année à l'autre
Les conditions de passages vers l'année suivante sont:

 1. Moyenne supérieure ou égale à 10/20 obtenue à plus de de la moitié des
    regroupements cohérents d’UE (niveaux de compétences). Ainsi, si l'année comporte 4
    compétences, il faut en valider au moins 3.
 2. Aucun regroupement cohérent d’UE < 8.
 3. Cas particulier du passage en BUT 3: nécessité d’avoir validé toutes les UE
    du BUT 1.
 
Note: La validation des deux UE du niveau d’une compétence emporte la validation de
 l’ensemble des UE du niveau inférieur de cette même compétence.

### Redoublements
La poursuite d'études dans un semestre pair d’une même année est *de droit* pour
tout étudiant. La poursuite d’études dans un semestre impair est possible si et
seulement si l’étudiant a obtenu :

 - la moyenne à plus de la moitié des regroupements cohérents d’UE ;
 - et une moyenne égale ou supérieure à 8 sur 20 à chaque regroupement cohérent
d’UE. La poursuite d'études dans le semestre 5 nécessite de plus la validation
de toutes les UE des semestres 1 et 2 dans les conditions de validation des
points 4.3 et 4.4, ou par décision de jury. 

Durant la totalité du cursus conduisant au bachelor universitaire de
technologie, l'étudiant peut être autorisé à redoubler une seule fois chaque
semestre dans la limite de *4 redoublements*. Le directeur de l'IUT peut autoriser
un redoublement supplémentaire en cas de force majeure dûment justifiée et
appréciée par ses soins. Tout refus d'autorisation de redoubler est pris après
avoir entendu l'étudiant à sa demande. Il doit être motivé et assorti de
conseils d'orientation.


### Obtention du diplôme

Le diplôme de BUT est obtenu lorsque toutes les compétences du parcours suivi
sont validées.
 
### Modules "bonus" (sport, culture, LV2)

Les modules hors formation comme le sport ou les langues vivantes supplémentaires
sont traditionnellement intégrés sous forme de "points de bonus" appliqués sur
la moyenne générale. Le BUT, on l'a vu, n'utilise plus la moyenne générale: le
bonus pourra donc être appliqué au niveau des moyennes UE: soit sur toutes
(bonus fixe ajouté à chaque UE), soit sur un sous-ensemble des UE du semestre.

Les règles précises du calcul de ce bonus sont malheureusement variables d'un
établissement à l'autre: ScoDoc 7 proposait plus d'une douzaine de variantes. La
situation sera identique avec le BUT et ScoDoc 9, et la mise en place d'une
fonction spécifique dans ScoDoc demandera un paramétrage particulier.

# Éditer ou importer une formation

ScoDoc permet d'importer des programmes de formations créés par d'autres
applications, comme Orébut, puis de les modifier pour introduire une *adaptation
locale*.

TODO: voir si on offre la possibilité de voir/gérer le delta entre le PN et le local.

# Modules et évaluations

## Créer une évaluation

Pour fixer les poids des évaluations du module, on peut employer plusieurs méthodes:

 - un nombre (poids de l'évaluation dans le module, sans préciser si cette
   évaluation affecte plus un UE qu'une autre);

 - cocher des apprentissages critiques (on rappelle que les AC sont associés à des niveaux de
   compétences, donc à 2 UE consécutives);

 - indiquer un poids par UE.

#### Coefficient et poids d'une évaluation
Afin de faciliter la tâche des enseignants, ScoDoc sépare le coefficient d'une
évaluation (qui donne sa place dans le module) et les poids (qui ajustent son
impact dans chaque UE). On introduit donc un coefficient $w_e$, et les poids
bruts $b_{e, u}$. Les vrais poids sont calculés comme

$$p_{e, u} =  w_e \, \frac{b_{e,u}}{\sum_u b_{e,u}}$$

#### Dialogue création/édition évaluation

<img src="/fig/but-dialog-eval-create.png" width="50%">

  - L'enseignant _doit_ renseigner le coefficient de l'évaluation. 
  - Par défaut, les poids valent 1 (la contribution de l'évaluation vers les
    différentes UE respecte alors le PN).
  - Si on décoche un AC, les poids sont mis à jour, au prorata du nombre d'AC
    dans chaque UE (compétence).
  


## Tableau de bord module

Fonctions de base, en plus de celles déjà présentes en ScoDoc 7:

 - Vérification de la conformité (tous les AC cochés dans le PN sont évalués)

 - Poids de chaque évaluation dans chaque UE et conformité au programme de la formation

En bas du tableau de bord du module on aura un tableau récapitulatif:

<img src="/fig/but-tableau-evals-module-ok.png" width="50%">

Dans le cas où les évaluations ne couvriraient pas toutes les UE (mauvais choix
des poids ou oubli d'une évaluation):

<img src="/fig/but-tableau-evals-module-ko.png" width="50%">



# Bulletins de notes

La quantité d'information à présenter rend la conception des bulletins de notes difficile.

## Modèle "Lillois"
Proposition de l'IUT de Lille: 

  - en ligne, les ressources, puis les SAÉ;
  - en colonnes, les UE;
  - dans chaque case, le coefficient et la note obtenue;
  - on peut ajouter les évaluations (lignes);
  - on pourrait ajouter les infos habituelles en colonnes: min/max/moy/rangs/...

Avantage: toutes les informations importantes sont présentées.

Inconvénients (?): beaucoup de cases vides, peu synthétique, pas évident à
exploiter pour un non spécialiste du BUT (poursuites d'études, employeurs).

<img src="/fig/but-bul-lille.png" width="50%">

## Modèle "Bordelais"
Cette proposition a été reçue sous différentes formes de plusieurs collègues.
L'idée est de présenter le bulletin en deux parties: d'abord les résultats de
chaque ressource et SAE, puis les résultats de chaque UE.

Un exemple préliminaire:

<img src="/fig/but-bul-bdx.png" width="50%">



# Tenue des Jury BUT

La tenue des jury BUT dans ScoDoc est très similaire à celle du DUT, avec moins
de décisions ad-hoc (compensations plus simples, moins de cas de mise en attente).

  - Validation des semestres (bien que cela ait peu de conséquences concrètes
    pour les semestres impairs.
  
  - Règles de compensation au sein de chaque niveau, pour validation de l'année. 



